    -----------------------------------------------------------------------------
     Microsoft VFP_OLE_Server Remote Command Execution
     url: http://www.microsoft.com

     Author: shinnai
     mail: shinnai[at]autistici[dot]org
     site: http://shinnai.altervista.org

     This was written for educational purpose. Use it at your own risk.
     Author will be not responsible for any damage.

     Not much more to say than using "foxcommand()" function, you can
     run applications passed as argument.

     Tested on Windows XP Professional SP2 all patched, with Internet Explorer 7
    -----------------------------------------------------------------------------

# milw0rm.com [2008-01-09]